@@ -304,7 +304,7 @@ impl Database {
     pub async fn aql_bind_vars<R>(
         &self,
         query: &str,
-        bind_vars: HashMap<&str, Value>,
+        bind_vars: HashMap<String, Value>,
     ) -> Result<Vec<R>, ClientError>
     where
         R: DeserializeOwned,
